function [b,h] = binary_fstat(f,f0,P,a0)
% Generate the Bessel-weighted matched filter (also generate Comb filter)
% 
% Inputs:
% f - Frequency bin list (i.e. hidden stats)
% f0 - Mean frequency for each sub-band
% P - Orbit period
% a0 - Projected orbital semimajor axis (i.e. asini)
% 
% Outputs:
% b - Bessel-weighted matched filter
% h - Comb filter (not used in the current search)

% Fstat power concentrated at [-c c]/P where c = 2*pi*a0*f0 
% f0 is fixed to setup matched filter for each 1-Hz sub-band 
c=(2*pi*a0*f0);
% Make it slightly wider than c
N=ceil(c)+100;
n=-N:N;
b0=besselj(n,c);
M=length(f);
% Identify the indices to place the matched filter in the 1-Hz band
% k indicates the interpolated indices at query points n/P using nearest interpolation, 1 is the extrapval for out of range values
k=interp1(f-mean(f),1:M,n/P,'nearest',1);
% Initialise the 1-Hz band matched filter
b=zeros(M,1);
% Place the filter
b(k)=abs(b0).^2;

% h is comb matched filter, not used in the search
h=zeros(M,1);
h(k)=1;

