function search_O1(freq,idx)
% This script is for O1 Sco X-1 search. 
% The search is separated into parallel 1-Hz sub-jobs.
% The start frequency for each sub-job is the overal start frequency plus job index.
%
% Inputs:
% freq - Start frequency for all the parallel jobs
% idx - Job index
% Start frequency for each sub-job: freq + idx
%
% Outputs:
% Save output files to the output directory.

format long g

startFreq = str2num(freq) + str2num(idx)

% Set directories and file name
dirName = '/home/ling.sun/O1/Viterbi/fstat/';
outdir = '/home/ling.sun/O1/Viterbi/output/';
outfile = strcat(outdir,'Viterbi-', num2str(startFreq),'.dat')

% Set parameters
a = 1.44
P = 68023.70496
steps = 13

% Read Fstats
tic
[f,X]=readfstats(dirName, startFreq, steps); 
toc

fmean=f(1)+0.5; % Take the mean value of each 1-Hz sub-band
g=[-0.1:0.01:0.1]; % asini grid (+/-10% uncertainty, may search larger uncertainty)
a0=(1+g)*a; % asini values being searched

for m=1:length(g)
    disp(sprintf('a0=%g',a0(m)))
    tic
    % Generate Bessel-weighted matched filter
    [b,h] = binary_fstat(f,fmean,P,a0(m)); 

	% Compute Bessel-weighted Fstat
    for n=1:steps
        Y(:,n)=fftshift(ifft(fft(X(:,n)).*fft(b)));
    end

    [path0(m,:),delta,psi,sc(m)] = viterbi_colFLT(3, Y);
    
    toc
end

% Get the optimal path for all asini searched
[maxsc,a0ind]=max(sc)
path=path0(a0ind,:)

% Save output file for each 1-Hz sub-band
fid=fopen(outfile,'wt');
fprintf(fid,'StartFreq\t%g\n',startFreq);
fprintf(fid,'Score\t%g\n',maxsc);
fprintf(fid,'Bin_a0\t%g\n',a0ind);
fprintf(fid,'Path');
fprintf(fid,'\n%d',path);
fclose(fid);

clear all
